@@ -19,7 +19,7 @@
 from pydsl.Check import check
 
 __author__ = "Nestor Arocha"
-__copyright__ = "Copyright 2008-2013, Nestor Arocha"
+__copyright__ = "Copyright 2008-2014, Nestor Arocha"
 __email__ = "nesaro@gmail.com"
 
 import logging
@@ -50,6 +50,9 @@ class NonTerminalSymbol(Symbol):
             return False
         return self.name == other.name and self.weight == other.weight
 
+    def __ne__(self, other):
+        return not self.__eq__(other)
+
 
 class TerminalSymbol(Symbol):
 
@@ -74,7 +77,6 @@ class TerminalSymbol(Symbol):
         """Checks if input is recognized as this symbol"""
         return check(self.gd, data)
 
-    @property
     def first(self):
         return self.gd.first
 
@@ -95,6 +97,9 @@ class NullSymbol(Symbol):
     def __eq__(self, other):
         return isinstance(other, NullSymbol)
 
+    def __ne__(self, other):
+        return not self.__eq__(other)
+
     def __bool__(self):
         return False
 
@@ -108,6 +113,9 @@ class EndSymbol(Symbol):
     def __eq__(self, other):
         return isinstance(other, EndSymbol)
 
+    def __ne__(self, other):
+        return not self.__eq__(other)
+
     def __bool__(self):
         return False
 
