@@ -1,9 +1,14 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
 
-#Copyright (C) 2008-2013 Nestor Arocha
+#Copyright (C) 2008-2014 Nestor Arocha
+
+
 
 def matchFun(myinput):
+    from collections import Iterable
+    if isinstance(myinput, Iterable):
+        myinput = "".join([str(x) for x in myinput])
     strnumber = str(myinput)
     try:
         number = int(strnumber)
